/*
* GStreamer
* Copyright (C) 2009 Carl-Anton Ingmarsson <ca.ingmarsson@gmail.com>
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Library General Public License for more details.
*
* You should have received a copy of the GNU Library General Public
* License along with this library; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "gstvideoframe.h"

GST_DEBUG_CATEGORY_STATIC (gst_video_frame_debug);
#define GST_CAT_DEFAULT gst_video_frame_debug

#define DEBUG_INIT(bla) \
GST_DEBUG_CATEGORY_INIT (gst_video_frame_debug, "gstvideoframe", 0, "Video Frame");

GST_DEFINE_MINI_OBJECT_TYPE (GstVideoFrame, gst_video_frame);

static GstVideoFrame *
_gst_video_frame_copy (GstVideoFrame * frame)
{
  GstVideoFrame *copy;

  copy = gst_video_frame_new ();

  copy->upstream_timestamp = frame->upstream_timestamp;
  copy->upstream_duration = frame->upstream_duration;
  copy->parsed_timestamp = frame->parsed_timestamp;
  copy->n_fields = frame->n_fields;
  if ((copy->sink_buffer = frame->sink_buffer))
    gst_buffer_ref (copy->sink_buffer);
  if ((copy->src_buffer = frame->src_buffer))
    gst_buffer_ref (copy->src_buffer);

  return copy;
}

static void
_gst_video_frame_free (GstVideoFrame * frame)
{
  if (frame->sink_buffer)
    gst_buffer_unref (frame->sink_buffer);
  if (frame->src_buffer)
    gst_buffer_unref (frame->src_buffer);

  g_slice_free1 (GST_MINI_OBJECT_SIZE (frame), frame);
}

GstVideoFrame *
gst_video_frame_new (void)
{
  GstVideoFrame *frame;

  frame = g_slice_new0 (GstVideoFrame);

  GST_LOG ("new %p", frame);

  gst_mini_object_init (GST_MINI_OBJECT_CAST (frame), GST_TYPE_VIDEO_FRAME,
      sizeof (GstVideoFrame));

  frame->mini_object.copy = (GstMiniObjectCopyFunction) _gst_video_frame_copy;
  frame->mini_object.free = (GstMiniObjectFreeFunction) _gst_video_frame_free;

  frame->upstream_timestamp = GST_CLOCK_TIME_NONE;
  frame->upstream_duration = GST_CLOCK_TIME_NONE;

  frame->parsed_timestamp = GST_CLOCK_TIME_NONE;

  frame->n_fields = 2;

  frame->sink_buffer = NULL;
  frame->src_buffer = NULL;

  return frame;
}

